@@ -10,7 +10,6 @@ use IO::Socket::INET;
 use IO::Socket::INET6;
 use Try::Tiny;
 use Capture::Tiny ':all';
-use IPv6::Address;
 
 =head1 NAME
 
@@ -18,11 +17,11 @@ Net::Hacky::Detect::IP - Hackily try different methods of attaining local system
 
 =head1 VERSION
 
-Version 0.019
+Version 0.020
 
 =cut
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 my $tools = {
     unix => {
@@ -185,20 +184,11 @@ sub scan {
         elsif ( ($type == 6 || $type == 0) && $testIP =~ m#:# && $testIP =~ m#[0-9]# && $testIP =~ m#^([a-f0-9:]+)$#) {
             # Copy $1 to $IP because it looks prettier
             my $IP = $1;
-            my $error = 0;
-        
-            # Test its valid
-            try {
-                my $test = IPv6::Address->new($IP);
-                $IP = $test->first_address;
-            } catch {
-                $error = 1;
-            };
 
             # Check we have not already dealt with this ip and its valid
             next if ($unique->{$IP});
             $unique->{$IP} = 1;
-            if (!$error || !$self->_checkIP6($IP)) { next }
+            if (!$self->_checkIP6($IP)) { next }
 
             # Push the valid ip into the return space
             push @$return,$IP;
@@ -337,15 +327,14 @@ sub _checkIP6 {
    # Now lets try listen on the ip.. see if we can bind to it, try three times on
     # random ports incase we bump into a busy one.
     for (1..3) {
-        my $fail=1;
         my $port = 1025+int(rand(64510));
         my $sock = IO::Socket::INET6->new(
             LocalAddr   =>  $host,
             LocalPort   =>  $port,
             Proto       =>  'tcp',
             ReuseAddr   =>  1
-        ) or $fail = 0;
-        if ($fail) {
+        );
+        if ($sock) {
             $bindsuccess=1;
             last;
         }
